aboutsummaryrefslogtreecommitdiff
path: root/src/include/cbfs.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/cbfs.h')
-rw-r--r--src/include/cbfs.h14
1 files changed, 9 insertions, 5 deletions
diff --git a/src/include/cbfs.h b/src/include/cbfs.h
index 60129d3bb2..7a984b8570 100644
--- a/src/include/cbfs.h
+++ b/src/include/cbfs.h
@@ -73,18 +73,22 @@ struct cbfs_props {
size_t size;
};
-/* Default CBFS locator .locate() callback that locates "COREBOOT" region. */
-int cbfs_default_props(struct cbfs_props *props);
+/* Default CBFS locator .locate() callback that locates "COREBOOT" region. This
+ function is exposed to reduce code duplication in other parts of the code
+ base. To obtain the correct region device the selection process is required
+ by way of cbfs_boot_region_device(). */
+int cbfs_default_region_device(struct region_device *rdev);
-/* Return < 0 on error otherwise props are filled out accordingly. */
-int cbfs_boot_region_properties(struct cbfs_props *props);
+/* Select the boot region device from the cbfs locators.
+ Return < 0 on error, 0 on success. */
+int cbfs_boot_region_device(struct region_device *rdev);
/* Object used to identify location of current cbfs to use for cbfs_boot_*
* operations. It's used by cbfs_boot_region_properties(). */
struct cbfs_locator {
const char *name;
/* Returns 0 on successful fill of cbfs properties. */
- int (*locate)(struct cbfs_props *props);
+ int (*locate)(struct region_device *rdev);
};
#endif